==> haskell-magic-1.1-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-magic.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: magic
version: 1.1
id: magic-1.1-F3eOg0g57IEA2dVEHkvXgd
key: magic-1.1-F3eOg0g57IEA2dVEHkvXgd
license: BSD-3-Clause
copyright: Copyright (c) 2005-2009 John Goerzen
maintainer: John Goerzen <jgoerzen@complete.org>
author: John Goerzen
stability: Alpha
synopsis: Interface to C file/magic library
description:
    This package provides a Haskell interface to the C libmagic library.
    With it, you can determine the type of a file by examining its contents
    rather than its name.  The Haskell interface provides a full-featured
    binding.
category: Text
abi: d303fc699be70e9743eb0cdc4e9dbdf7
exposed: True
exposed-modules:
    Magic Magic.Data Magic.Init Magic.Operations Magic.Types
hidden-modules: Magic.Utils Magic.TypesLL
import-dirs: /usr/lib/ghc-8.4.3/site-local/magic-1.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/magic-1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/magic-1.1
hs-libraries: HSmagic-1.1-F3eOg0g57IEA2dVEHkvXgd
extra-libraries:
    magic
depends:
    base-4.11.1.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-magic/html/magic.haddock
haddock-html: /usr/share/doc/haskell-magic/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-magic-1.1-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-magic.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: magic
version: 1.1
id: magic-1.1-Li4qC2EFmFj3eSH3BrxalF
key: magic-1.1-Li4qC2EFmFj3eSH3BrxalF
license: BSD-3-Clause
copyright: Copyright (c) 2005-2009 John Goerzen
maintainer: John Goerzen <jgoerzen@complete.org>
author: John Goerzen
stability: Alpha
synopsis: Interface to C file/magic library
description:
    This package provides a Haskell interface to the C libmagic library.
    With it, you can determine the type of a file by examining its contents
    rather than its name.  The Haskell interface provides a full-featured
    binding.
category: Text
abi: 83cfa6e872e58e8f7de22678729c9ed6
exposed: True
exposed-modules:
    Magic Magic.Data Magic.Init Magic.Operations Magic.Types
hidden-modules: Magic.Utils Magic.TypesLL
import-dirs: /usr/lib/ghc-8.6.1/site-local/magic-1.1
library-dirs: /usr/lib/ghc-8.6.1/site-local/magic-1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/magic-1.1
hs-libraries: HSmagic-1.1-Li4qC2EFmFj3eSH3BrxalF
extra-libraries:
    magic
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-magic/html/magic.haddock
haddock-html: /usr/share/doc/haskell-magic/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
